# pwsh{
$modname = Get-ItemPropertyValue .\ Name
Write-Host Working on files for `"$modname`"
# $Args[0]
$config = Get-Content ..\PD3_BAP.config
$moddir  = $config[7]
switch ($Args[0]) {
   {$_ -match 'SFX'} {$srctype  = "Media"}
   {$_ -match 'Voices'} {$srctype = "Localized\English_US_\Media"}
    Default {$srctype  = "Media"}
}
$srcdir  = (Join-Path $config[8] $srctype)
$pakdir  = $config[9]
$wwdir   = $config[10]
$projdir = $config[11]
# $moddir,$srcdir,$srctype,$pakdir,$wwdir,$projdir
Write-Host ███████████████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░░░░░░░░░░
Write-Host ▌ Moving files from source to staging...
foreach ($file in (Get-Item ((Join-Path $srcdir *.ubulk)))) {
    if (Get-Item ((Join-Path $srcdir *.ubulk))) {
        $basename = (Get-Item $file).BaseName
        # Write-Host (Join-Path $srcdir $basename".ubulk")
        # Write-Host (Join-Path $moddir $modname $basename".ubulk")
        Move-Item (Join-Path $srcdir $basename".uasset") (Join-Path $moddir $modname $basename".uasset") -Force
        Move-Item (Join-Path $srcdir $basename".ubulk")  (Join-Path $moddir $modname $basename".ubulk") -Force
        Move-Item (Join-Path $srcdir $basename".uexp")   (Join-Path $moddir $modname $basename".uexp") -Force
        Write-Host ▌ Moving files for $basename
    }
}
Write-Output "<?xml version=`"1.0`" encoding=`"UTF-8`"?>" > list.wsources
Write-Output "<ExternalSourcesList SchemaVersion=`"1`" Root=`"`">" >> list.wsources
foreach ($file in (Get-Item (Join-Path $moddir $modname *) -Include ('*.wav', '*.mp3', '*.ogg'))) {
    $basename = (Get-Item $file).BaseName
    # $basename
    if (Test-Path $file".backup" -PathType Leaf) {
        # Write-Host Backup for $file already exists.
    } else {
        Copy-Item $file $file".backup"
        ffmpeg.exe -hide_banner -loglevel error -i $file -r 44100 -c:a pcm_s16le -y $basename".wav"
    }    
}
foreach ($file in (Get-Item (Join-Path $moddir $modname *.wav) )) {
    Write-Output "  <Source Path=`"$file`" Conversion=`"PCM Auto Detect High`" />" >> list.wsources
}
Write-Output "</ExternalSourcesList>" >> list.wsources
Write-Host ███████████████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░░░░░░░░░░
Write-Host ▌ Converting audio files...
# Write-Host Start-Process -NoNewWindow -Wait -FilePath $wwdir -ArgumentList @('convert-external-source'; "`"$projdir`"", '--source-file',"`"$moddir\$modname\list.wsources`"", '--output Windows',"`"$moddir\$modname`"", '--no-wwise-dat')
Start-Process -NoNewWindow -Wait -FilePath $wwdir  -ArgumentList @('convert-external-source',"`"$projdir`"", '--source-file',"`"$moddir\$modname\list.wsources`"", '--output Windows',"`"$moddir\$modname`"", '--no-wwise-dat', '--quiet')
Write-Host ███████████████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░░░░░░░░░░
foreach ($file in (Get-Item ((Join-Path $moddir $modname *.ubulk)))) {
$basename = (Get-Item $file).BaseName
Write-Host ▌ Original audio file: (".\",$basename,".ubulk" -join '')
# Write-Host $file
$filesize = $file.Length
$hex = "{0:X8}" -f $filesize
# Write-Host $hex
$result = For($i = $hex.length -1 ; $i -ge 0 ; $i-= 2){$hex[$i-1],$hex[$i]," "}
$result = $result -join ''
$filesizehalf = $filesize / 2
# $filesizehalf
$hexhalf = "{0:X8}" -f $filesizehalf
# Write-Host $hex
$resulthalf = For($i = $hexhalf.length -1 ; $i -ge 0 ; $i-= 2){$hexhalf[$i-1],$hexhalf[$i]," "}
$resulthalf = $resulthalf -join ''
$filesizewem = (Get-Item (".\",$basename,".wem" -join '')).Length
$hexwem = "{0:X8}" -f $filesizewem
# Write-Host $hexwem
$resultwem = For($i = $hexwem.length -1 ; $i -ge 0 ; $i-= 2){$hexwem[$i-1],$hexwem[$i]," "}
$resultwem = $resultwem -join ''
# $resultwem
$uexp_orig = Get-Content (Get-Item (".\",$basename,".uexp" -join '')) -AsByteStream
# $uexp_orig
$uexp_hex = $uexp_orig.ForEach('ToString', 'X2') -join ' '
# $uexp_hex
# $result
# $resultwem.GetType()
# $uexp_hex.Contains($result)
if ($uexp_hex.Contains($result)) {
    Write-Host ▌ Original file size: $filesize Bytes
    Write-Host ▌ Converted wem file: (".\",$basename,".wem" -join '')
    Write-Host ▌ New file size: $filesizewem Bytes
    Write-Host ▌ Writing new uexp for (".\",$basename,".uexp" -join '')
    [string[]] $uexp_new = $uexp_hex.Replace($result,$resultwem)
} elseif ($uexp_hex.Contains($resulthalf)){
    Write-Host ▌ Original file size: $filesizehalf Bytes
    Write-Host ▌ Converted custom file: (".\",$basename,".wem" -join '')
    Write-Host ▌ New file Size: $filesizewem Bytes
    Write-Host ▌ Writing new uexp for (".\",$basename,".uexp" -join '')
    [string[]] $uexp_new = $uexp_hex.Replace($resulthalf,$resultwem)
} else {
    Write-Host ▌ Could not find the original file size in uexp.
}
# $uexp_new
# $uexp_new = [System.Text.Encoding]::ASCII.GetBytes($uexp_new)
# $uexp_new
[byte[]] $uexp_new = -split $uexp_new -replace '^','0x'
# $uexp_new
# [byte[]]$uexp_new = $uexp_new
# $uexp_new = [System.Text.Encoding]::ASCII.GetString($uexp_new)
if (-Not (Test-Path (Join-Path $pakdir $modname "PAYDAY3\Content\WwiseAudio" $srctype))) {
    New-Item -ItemType "Directory" (Join-Path $pakdir $modname "PAYDAY3\Content\WwiseAudio" $srctype)
}
Set-Content (Join-Path $pakdir $modname "PAYDAY3\Content\WwiseAudio\" $srctype $basename".uexp") -AsByteStream -Value $uexp_new -Force
Write-Host ▌ Rewriting uexp complete!
Write-Host ███████████████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▒▒▒▒▒▒▒▒▒▒▒▒▒▒░░░░░░░░░░░░░░
Move-Item (Join-Path $moddir $modname $basename".wem") (Join-Path $pakdir $modname "PAYDAY3\Content\WwiseAudio" $srctype $basename".ubulk") -Force
Copy-Item (Join-Path $moddir $modname $basename".uasset") (Join-Path $pakdir $modname "PAYDAY3\Content\WwiseAudio" $srctype $basename".uasset")
}
Pause
# }